import { DialogBase } from '../../libappbase/dialogbase';
import { DurationSelector } from '../../e2elib/lib/src/pageobjects/durationselector.component';
import { DropDownListSOP } from '../../libappsop/dropdownlistsop';

export class DialogCreateEditTransitionType extends DialogBase {
  private readonly _dsMinDuration = new DurationSelector('DurationSelectorMinDuration');
  private readonly _dsMaxDuration = new DurationSelector('DurationSelectorMaxDuration');

  private readonly _ddlUnit = new DropDownListSOP('DropDownListUnit');

  private readonly _ddlFromCampaignType = new DropDownListSOP('DropDownListFromCampaignType');
  private readonly _ddlToCampaignType = new DropDownListSOP('DropDownListToCampaignType');

  public constructor() {
    super('DialogCreateEditTransitionType', 'btnOk', 'btnCancel');
  }

  /**
   * Update Transition Type values in the dialog
   *
   * @param unit unit name
   * @param fromCampaignType From campaign type name
   * @param toCampaignType To campaign type name
   * @param minDay min day duration
   * @param maxDay max day duration
   */
  public async updateTransitionTypeValue(unit: string, fromCampaignType: string, toCampaignType: string, minDay?: string, maxDay?: string): Promise<void> {
    await this._ddlUnit.selectItemSOP(unit);
    await this._ddlFromCampaignType.selectItemSOP(fromCampaignType);
    await this._ddlToCampaignType.selectItemSOP(toCampaignType);
    if (minDay) {
      await this._dsMinDuration.setDay(minDay);
    }

    if (maxDay) {
      await this._dsMaxDuration.setDay(maxDay);
    }
  }
}
